@@ -306,19 +306,21 @@ Net::CalDAVTalk - Module to talk CalDAV and give a JSON interface to the data
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
 
-This module currently talks an old version of the FastMail internal protocol,
-which is kinda useless, but it's a good starting point to build something better.
+This module is the initial release of the code used at FastMail for talking
+to CalDAV servers.  It's quite specific to an early version of our API, so
+while it might be useful to others, it's being pushed to CPAN more because
+the Cassandane test suite needs it.
 
-An example:
+See Net::DAVTalk for details on how to specify hosts and paths.
 
     my $CalDAV = Net::CalDAVTalk->new(
         user => $service->user(),
@@ -330,9 +332,34 @@ An example:
         expandurl => 1,
     );
 
+or using DNS:
+
+    my $domain = $user;
+    $domain =~ s/.*\@//;
+
+    my $url;
+    my ($reply) = $Resolver->search("_caldavs._tcp.$domain", "srv");
+    if ($reply) {
+      my @d = $reply->answer;
+      if (@d) {
+        my $host = $d[0]->target();
+        my $port = $d[0]->port();
+        $url = "https://$host";
+        $url .= ":$port" unless $port eq 443;
+      }
+    }
+
 This will use the '/.well-known/caldav' address to find the actual current user
 principal, and from there the calendar-home-set for further operations.
 
+    my $foo = Net::CalDAVTalk->new(
+       user => $user,
+       password => $password,
+       url => $url,
+       expandurl => 1,
+    );
+
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new(%args)
@@ -348,8 +375,6 @@ and some Cyrus specific namespaces for all XML requests.
 
 =cut
 
-# General methods
-
 sub new {
   my ($Class, %Params) = @_;
 
@@ -417,6 +442,16 @@ Delete the named calendar from the server (shorturl - see Net::DAVTalk)
 
 =cut
 
+=head2 $Cal->DeleteCalendar($calendarId)
+
+Delete the calendar with collection name $calendarId (full or relative path)
+
+e.g.
+
+    $Cal->DeleteCalendar('Default');
+
+=cut
+
 sub DeleteCalendar {
   my ($Self, $calendarId) = @_;
 
@@ -2673,7 +2708,7 @@ L<http://search.cpan.org/dist/Net-CalDAVTalk/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015 Bron Gondwana.
+Copyright 2015 FastMail Pty Ltd.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
